"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExtensionReflection = void 0;
const typedoc_1 = require("typedoc");
const kind_1 = require("./kind");
/**
 * A reflection containing data about commands and/or execute methods.
 *
 * Methods may be invoked directly by Handlebars templates.
 */
class ExtensionReflection extends typedoc_1.DeclarationReflection {
    /**
     *
     * @param name Name of module containing commands
     * @param parent Module containing commands
     * @param moduleCommands Data containing commands and execute methods
     * @todo Determine the kind by inspecting `package.json` or smth
     */
    constructor(name, parent, moduleCommands) {
        const { routeMap, execMethodDataSet } = moduleCommands;
        const kind = (name.includes('driver')
            ? kind_1.AppiumPluginReflectionKind.Driver
            : name.includes('plugin')
                ? kind_1.AppiumPluginReflectionKind.Plugin
                : kind_1.AppiumPluginReflectionKind.Extension);
        super(name, kind, parent);
        this.parent = parent;
        this.routeMap = routeMap;
        this.execMethodDataSet = execMethodDataSet;
    }
    /**
     * Returns `true` if there are any "execute commands" in this set.
     *
     * Used by templates
     */
    get hasExecuteMethod() {
        return Boolean(this.execMethodCount);
    }
    /**
     * Returns `true` if there are any "regular" commands in this set.
     *
     * Used by templates
     */
    get hasRoute() {
        return Boolean(this.routeCount);
    }
    /**
     * Returns number of routes ("commands") in this in this data
     */
    get routeCount() {
        return this.routeMap.size;
    }
    /**
     * Returns number of execute methods in this data
     */
    get execMethodCount() {
        return this.execMethodDataSet.size;
    }
}
exports.ExtensionReflection = ExtensionReflection;
//# sourceMappingURL=extension.js.map